@@ -2,9 +2,10 @@
 NMEA Protocol Poll payload definitions
 
 THESE ARE THE PAYLOAD DEFINITIONS FOR _POLL_ MESSAGES _TO_ THE RECEIVER
-(i.e. Message Poll requests)
+(i.e. Message Poll requests).
 
-NB: Attribute names must be unique within each message id
+NB: Attribute names must be unique within each message id.
+NB: Avoid reserved names 'msgID', 'talker', 'payload', 'checksum'.
 
 Created on 4 Mar Sep 2021
 
